@@ -166,7 +166,7 @@ class Page(pyscp.core.Page):
             user = cells[4].text
             time = parse_element_time(cells[5])
             comment = cells[6].text if cells[6].text else None
-            yield pyscp.core.Revision(rev_id, number, user, time, comment)
+            yield pyscp.core.Revision(rev_id, number, User(user), time, comment)
 
     @pyscp.utils.cached_property
     def votes(self):
@@ -537,6 +537,120 @@ class Wiki(pyscp.core.Wiki):
             status, notes = [i if i else None for i in (status, notes)]
             yield pyscp.core.Image(url, source, status, notes, None)
 
+class User(pyscp.core.User):
+    """
+    Create a User object.
+    """
+
+    ###########################################################################
+    # Special Methods
+    ###########################################################################
+    
+    def __init__(self, username):
+        super().__init__(username)
+        self.req = InsistentRequest()
+    
+    def __repr__(self):
+        return '{}.{}({})'.format(
+            self.__module__,
+            self.__class__.__name__,
+            repr(self.user))
+    
+    ###########################################################################
+    # Internal Methods
+    ###########################################################################
+    
+    @pyscp.utils.log_errors(log.warning)
+    def _module(self, _name, **kwargs):
+        response = self.req.post(
+            'http://www.wikidot.com/ajax-module-connector.php',
+            data=dict(user_id=self.id,
+                moduleName=_name,
+                wikidot_token7='123456',
+                **kwargs),
+            headers={'Content-Type': 'application/x-www-form-urlencoded;', 'Cookie': 'wikidot_token7=123456;'}).json()
+        if response['status'] != 'ok':
+            log.error(response)
+            raise RuntimeError(response.get('message') or response['status'])
+        return response
+    
+    @pyscp.utils.cached_property
+    def _pdata(self):
+        data = self.req.get(self.url).text
+        soup = bs4.BeautifulSoup(data, 'lxml')
+        return (int(re.search('userId = ([0-9]+);', data).group(1)),
+                self.parse_data(soup))
+    
+    @pyscp.utils.log_errors(log.warning)
+    def parse_data(self, soup):
+        content = soup.find(id='page-content')
+        time = parse_element_time(content)
+        data = soup.find('div', {'id': 'user-info-area'}).find_all('dd')
+        new_data = []
+        for i in data:
+            new_data.append(i.get_text())
+        if 'none' in new_data[2]:
+            level = 'none'
+        elif 'low' in new_data[2]:
+            level = 'low'
+        elif 'medium' in new_data[2]:
+            level = 'medium'
+        elif 'high' in new_data[2] and 'very' not in new_data[2]:
+            level = 'high'
+        elif 'very high' in new_data[2]:
+            level = 'very high'
+        elif 'guru' in new_data[2]:
+            level = 'guru'
+        parsed_data = {'name': self.username, 'time': time, 'type': new_data[1].replace('\n','').replace(' ',''), 'level': level}
+        return parsed_data
+    
+    @property
+    def id(self):
+        return self._pdata[0]
+    
+    ###########################################################################
+    # Properties
+    ###########################################################################
+    
+    @property
+    def join_time(self):
+        return self._pdata[1]['time']
+    
+    @property
+    def type(self):
+        return self._pdata[1]['type']
+    
+    @property
+    def karma(self):
+        return self._pdata[1]['level']
+    
+    @property
+    def member(self):
+        data = self._module('userinfo/UserInfoMemberOfModule')['body']
+        soup = bs4.BeautifulSoup(data, 'lxml')
+        result = []
+        for e in soup.find_all('a'):
+            result.append(Wiki(e.get('href')))
+        return result
+    
+    @property
+    def moderator(self):
+        data = self._module('userinfo/UserInfoModeratorOfModule')['body']
+        soup = bs4.BeautifulSoup(data, 'lxml')
+        result = []
+        for e in soup.find_all('a'):
+            result.append(Wiki(e.get('href')))
+        return result
+    
+    @property
+    def admin(self):
+        data = self._module('userinfo/UserInfoAdminOfModule')['body']
+        soup = bs4.BeautifulSoup(data, 'lxml')
+        result = []
+        for e in soup.find_all('a'):
+            result.append(Wiki(e.get('href')))
+        return result
+
 ###############################################################################
 
 
